@@ -31,15 +31,15 @@ import re
 import signal
 import string
 import sys
+import sysconfig
 import tokenize
 
-import distutils.sysconfig
 import pyflakes.api
 import pyflakes.messages
 import pyflakes.reporter
 
 
-__version__ = '1.5.1'
+__version__ = '1.5.2'
 
 
 _LOGGER = logging.getLogger('autoflake')
@@ -55,19 +55,18 @@ MAX_PYTHON_FILE_DETECTION_BYTES = 1024
 
 def standard_paths():
     """Yield paths to standard modules."""
-    for is_plat_spec in [True, False]:
-
+    paths = sysconfig.get_paths()
+    path_names = ['stdlib', 'platstdlib']
+    for path_name in path_names:
         # Yield lib paths.
-        path = distutils.sysconfig.get_python_lib(
-            standard_lib=True,
-            plat_specific=is_plat_spec,
-        )
-        yield from os.listdir(path)
+        if path_name in paths:
+            path = paths[path_name]
+            yield from os.listdir(path)
 
-        # Yield lib-dynload paths.
-        dynload_path = os.path.join(path, 'lib-dynload')
-        if os.path.isdir(dynload_path):
-            yield from os.listdir(dynload_path)
+            # Yield lib-dynload paths.
+            dynload_path = os.path.join(path, 'lib-dynload')
+            if os.path.isdir(dynload_path):
+                yield from os.listdir(dynload_path)
 
 
 def standard_package_names():
@@ -494,6 +493,7 @@ def filter_code(
     remove_all_unused_imports=False,
     remove_duplicate_keys=False,
     remove_unused_variables=False,
+    remove_rhs_for_unused_variables=False,
     ignore_init_module_imports=False,
 ):
     """Yield code with unused imports removed."""
@@ -568,7 +568,9 @@ def filter_code(
                 previous_line=previous_line,
             )
         elif line_number in marked_variable_line_numbers:
-            result = filter_unused_variable(line)
+            result = filter_unused_variable(
+                line, drop_rhs=remove_rhs_for_unused_variables,
+            )
         elif line_number in marked_key_line_numbers:
             result = filter_duplicate_key(
                 line, line_messages[line_number],
@@ -641,7 +643,7 @@ def filter_unused_import(
         )
 
 
-def filter_unused_variable(line, previous_line=''):
+def filter_unused_variable(line, previous_line='', drop_rhs=False):
     """Return line if used, otherwise return None."""
     if re.match(EXCEPT_REGEX, line):
         return re.sub(r' as \w+:$', ':', line, count=1)
@@ -658,7 +660,11 @@ def filter_unused_variable(line, previous_line=''):
             # Rather than removing the line, replace with it "pass" to avoid
             # a possible hanging block with no body.
             value = 'pass' + get_line_ending(line)
+            if drop_rhs:
+                return get_indentation(line) + value
 
+        if drop_rhs:
+            return ''
         return get_indentation(line) + value
     else:
         return line
@@ -789,7 +795,8 @@ def get_line_ending(line):
 def fix_code(
     source, additional_imports=None, expand_star_imports=False,
     remove_all_unused_imports=False, remove_duplicate_keys=False,
-    remove_unused_variables=False, ignore_init_module_imports=False,
+    remove_unused_variables=False, remove_rhs_for_unused_variables=False,
+    ignore_init_module_imports=False,
 ):
     """Return code with all filtering run on it."""
     if not source:
@@ -811,6 +818,9 @@ def fix_code(
                         remove_all_unused_imports=remove_all_unused_imports,
                         remove_duplicate_keys=remove_duplicate_keys,
                         remove_unused_variables=remove_unused_variables,
+                        remove_rhs_for_unused_variables=(
+                            remove_rhs_for_unused_variables
+                        ),
                         ignore_init_module_imports=ignore_init_module_imports,
                     ),
                 ),
@@ -859,6 +869,9 @@ def _fix_file(
         remove_all_unused_imports=args['remove_all_unused_imports'],
         remove_duplicate_keys=args['remove_duplicate_keys'],
         remove_unused_variables=args['remove_unused_variables'],
+        remove_rhs_for_unused_variables=(
+            args['remove_rhs_for_unused_variables']
+        ),
         ignore_init_module_imports=ignore_init_module_imports,
     )
 
@@ -1117,6 +1130,7 @@ def merge_configuration_file(args):
                 'check', 'expand-star-imports', 'ignore-init-module-imports',
                 'in-place', 'recursive', 'remove-all-unused-imports',
                 'remove-duplicate-keys', 'remove-unused-variables',
+                'remove-rhs-for-unused-variables',
             }:
                 # boolean properties
                 if isinstance(value, str):
@@ -1192,6 +1206,11 @@ def _main(argv, standard_out, standard_error, standard_input=None):
         '--remove-unused-variables', action='store_true',
         help='remove unused variables',
     )
+    parser.add_argument(
+        '--remove-rhs-for-unused-variables', action='store_true',
+        help='remove RHS of statements when removing unused '
+             'variables (unsafe)',
+    )
     parser.add_argument(
         '--version', action='version',
         version='%(prog)s ' + __version__,
@@ -1246,6 +1265,15 @@ def _main(argv, standard_out, standard_error, standard_input=None):
         _LOGGER.error('Using both --remove-all and --imports is redundant')
         return 1
 
+    if args.remove_rhs_for_unused_variables and not (
+        args.remove_unused_variables
+    ):
+        _LOGGER.error(
+            'Using --remove-rhs-for-unused-variables only makes sense when '
+            'used with --remove-unused-variables',
+        )
+        return 1
+
     if args.exclude:
         args.exclude = _split_comma_separated(args.exclude)
     else:
